==> cpp11armadillo_0.2.5.tgz: cpp11armadillo/include/armadillo/newarp_SparseGenMatProd_meat.hpp <==
// SPDX-License-Identifier: Apache-2.0
//
// Copyright 2008-2016 Conrad Sanderson (http://conradsanderson.id.au)
// Copyright 2008-2016 National ICT Australia (NICTA)
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
// ------------------------------------------------------------------------

namespace newarp {

template <typename eT>
inline SparseGenMatProd<eT>::SparseGenMatProd(const SpMat<eT>& mat_obj)
    : op_mat(mat_obj), n_rows(mat_obj.n_rows), n_cols(mat_obj.n_cols) {
  arma_extra_debug_sigprint();

  op_mat_st = op_mat.st();  // pre-calculate transpose
}

// Perform the matrix-vector multiplication operation \f$y=Ax\f$.
// y_out = A * x_in
template <typename eT>
inline void SparseGenMatProd<eT>::perform_op(eT* x_in, eT* y_out) const {
  arma_extra_debug_sigprint();

  // // OLD METHOD
  //
  // const Col<eT> x(x_in , n_cols, false, true);
  //       Col<eT> y(y_out, n_rows, false, true);
  //
  // y = op_mat * x;

  // NEW METHOD

  const Row<eT> x(x_in, n_cols, false, true);
  Row<eT> y(y_out, n_rows, false, true);

  y = x * op_mat_st;
}

}  // namespace newarp

==> cpp11armadillo_0.3.3.tgz: cpp11armadillo/include/armadillo/newarp_SparseGenMatProd_meat.hpp <==
// SPDX-License-Identifier: Apache-2.0
//
// Copyright 2008-2016 Conrad Sanderson (http://conradsanderson.id.au)
// Copyright 2008-2016 National ICT Australia (NICTA)
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
// ------------------------------------------------------------------------

namespace newarp {

template <typename eT>
inline SparseGenMatProd<eT>::SparseGenMatProd(const SpMat<eT>& mat_obj)
    : op_mat(mat_obj), n_rows(mat_obj.n_rows), n_cols(mat_obj.n_cols) {
  arma_debug_sigprint();

  op_mat_st = op_mat.st();  // pre-calculate transpose
}

// Perform the matrix-vector multiplication operation \f$y=Ax\f$.
// y_out = A * x_in
template <typename eT>
inline void SparseGenMatProd<eT>::perform_op(eT* x_in, eT* y_out) const {
  arma_debug_sigprint();

  // // OLD METHOD
  //
  // const Col<eT> x(x_in , n_cols, false, true);
  //       Col<eT> y(y_out, n_rows, false, true);
  //
  // y = op_mat * x;

  // NEW METHOD

  const Row<eT> x(x_in, n_cols, false, true);
  Row<eT> y(y_out, n_rows, false, true);

  y = x * op_mat_st;
}

}  // namespace newarp
